==> fengoffice_1.7.5.zip: fengoffice/language/de_de/objects.php <==
<?php return array(
	'user' => 'Benutzer',
	'group' => 'Gruppe',
	'groups' => 'Gruppen',
	'users' => 'Benutzer',
	'member' => 'Mitglied',
	'members' => 'Mitglieder',
	'company' => 'Firma',
	'companies' => 'Firmen',
	'client' => 'Kunde',
	'clients' => 'Kunden',
	'package' => 'Paket',
	'project' => 'Arbeitsbereich',
	'projects' => 'Arbeitsbereiche',
	'message' => 'Notiz',
	'messages' => 'Notizen',
	'comment' => 'Kommentar',
	'comments' => 'Kommentare',
	'milestone' => 'Meilenstein',
	'milestones' => 'Meilensteine',
	'task' => 'Aufgabe',
	'subtasks' => 'Teilaufgabe',
	'tasks' => 'Aufgaben',
	'task list' => 'Aufgabenliste',
	'task lists' => 'Aufgabenlisten',
	'tag' => 'Schlagwort',
	'tags' => 'Schlagworte',
	'attachment' => 'Anlage',
	'attachments' => 'Anlagen',
	'object subscribers' => 'Abonnenten',
	'form' => 'Formular',
	'forms' => 'Formulare',
	'file' => 'Datei',
	'files' => 'Dateien',
	'file revision' => 'Dateirevision',
	'file revisions' => 'Dateirevisionen',
	'revision' => 'Revision',
	'revisions' => 'Revisionen',
	'folder' => 'Ordner',
	'folders' => 'Ordner',
	'configuration category' => 'Konfigurationskategorie',
	'configuration categories' => 'Konfigurationskategorien',
	'handin' => 'Hand-In',
	'handins' => 'Hand-Ins',
	'owner company' => 'Unser Unternehmen',
	'client companies' => 'Andere Unternehmen',
	'open milestone' => 'Offener Meilenstein',
	'open milestones' => 'Offene Meilensteine',
	'completed milestone' => 'Abgeschlossener Meilenstein',
	'completed milestones' => 'Abgeschlossene Meilensteine',
	'late milestones' => 'Verspätete Meilensteine',
	'late milestones and tasks' => 'Verspätete Meilensteine und Aufgaben',
	'today milestones' => 'Heute fällige Meilensteine',
	'upcoming milestones' => 'Anstehende Meilensteine',
	'completed task list' => 'Abgeschlossene Aufgabe',
	'completed task lists' => 'Abgeschlossene Aufgaben',
	'open task list' => 'Offene Aufgabe',
	'open task lists' => 'Offene Aufgaben',
	'active project' => 'Aktueller Arbeitsbereich',
	'active projects' => 'Aktuelle Arbeitsbereiche',
	'finished project' => 'Geschlossener Arbeitsbereich',
	'finished projects' => 'Geschlossene Arbeitsbereiche',
	'linked object' => 'Verknüpftes Objekt',
	'linked objects' => 'Verknüpfte Objekte',
	'important message' => 'Wichtige Nachricht',
	'important messages' => 'Wichtige Nachrichten',
	'important file' => 'Wichtige Datei',
	'important files' => 'Wichtige Dateien',
	'parent task' => 'Hauptaufgabe',
	'private message' => 'Private Nachricht',
	'private milestone' => 'Privater Meilenstein',
	'private task list' => 'Private Aufgabenliste',
	'private comment' => 'Privater Kommentar',
	'private file' => 'Private Datei',
	'file contents' => 'Dateiinhalt',
	'emailunclassified' => 'E-Mail',
	'object reminders' => 'Erinnerungen',
	'add object reminder' => 'Erinnerung hinzufügen',
	'load file' => 'Datei laden',
	'time' => 'Zeit',
	'reporting' => 'Berichte',
	'create document' => 'Dokumente hinzufügen',
	'create presentation' => 'Präsentationen hinzufügen',
	'modify object subscribers' => 'Abonnenten bearbeiten',
	'subscription modified successfully' => 'Abonnenten erfolgreich bearbeitet!',
	'urgent milestone' => 'Dringend',
	'the message' => 'Notiz',
	'the email' => 'E-Mail',
	'the emailunclassified' => 'E-Mail',
	'the contact' => 'Kontakt',
	'the company' => 'Firma',
	'the event' => 'Termin',
	'the file' => 'Datei',
	'the file revision' => 'Dateirevision',
	'the task' => 'Aufgabe',
	'the milestone' => 'Meilenstein',
	'the webpage' => 'Weblink',
	'the comment' => 'Kommentar',
	'the user' => 'Benutzer',
	'the project' => 'Arbeitsbereich',
	'activity add' => '{1} fügte {0} „{2}“ hinzu.',
	'activity edit' => '{1} bearbeitete {0} „{2}“.',
	'activity delete' => '{1} löschte {0} „{2}“.',
	'activity trash' => '{1} löschte {0} „{2}“.',
	'activity untrash' => '{1} stellte {0} „{2}“ aus dem Papierkorb wieder her.',
	'activity open' => '{1} eröffnete {0} „{2}“ wieder.',
	'activity close' => '{1} markierte {0} „{2}“ als „Erledigt“.',
	'activity subscribe' => '{1} abonnierte für {3} - {0}: „{2}“.',
	'activity unsubscribe' => '{1} kündigte Abonnent von {3} für {0} „{2}“.',
	'activity tag' => '{1} verschlagwortete {0} „{2}“ als „{3}“.',
	'activity untag' => '{1} löschte die Schlagwörter von {0} „{2}“.',
	'activity comment' => '{1} kommentierte {0} „{2}“:<br />    „{3}“',
	'activity link' => '{1} verknüpfte {0} „{2}“ mit {3} {4}.',
	'activity unlink' => '{1} löschte die Verknüpfung zwischen {0} „{2}“ und {3} {4}.',
	'activity login' => '{0} hat sich angemeldet.',
	'activity logout' => '{0} hat sich abgemeldet.',
	'activity archive' => '{1} archivierte {0} „{2}“.',
	'activity unarchive' => '{1} stellte {0} „{2}“ aus dem Archiv wieder her.',
	'activity move from to' => '{1} verschob {0} „{2}“ von {3} nach {4}.',
	'activity move from' => '{1} verschob {0} „{2}“ von {3}.',
	'activity move to' => '{1} verschob {0} „{2}“ nach {3}.',
	'activity move' => '{1} verschob {0} „{2}“ von {3}.',
	'activity copy to' => '{1} kopierte {0} „{2}“ nach {3}.',
	'activity copy' => '{1} kopierte {0} „{2}“.',
	'activity read' => '{1} las {0} „{2}“.',
	'activity download' => '{1} lud {0} „{2}“ herunter.',
	'x users' => '{0} Benutzer{1}',
	'the file_revision' => 'die Dateirevision',
	'activity checkout' => '{1} gesperrt {0} {2}',
	'activity checkin' => '{1} freigegeben {0} {2}',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/de_de/objects.php <==
<?php return array(
	'user' => 'Benutzer',
	'group' => 'Gruppe',
	'groups' => 'Gruppen',
	'users' => 'Benutzer',
	'member' => 'Mitglied',
	'members' => 'Mitglieder',
	'company' => 'Firma',
	'companies' => 'Firmen',
	'client' => 'Kunde',
	'clients' => 'Kunden',
	'package' => 'Paket',
	'project' => 'Arbeitsbereich',
	'projects' => 'Arbeitsbereiche',
	'message' => 'Notiz',
	'messages' => 'Notizen',
	'comment' => 'Kommentar',
	'comments' => 'Kommentare',
	'milestone' => 'Meilenstein',
	'milestones' => 'Meilensteine',
	'task' => 'Aufgabe',
	'subtasks' => 'Teilaufgabe',
	'tasks' => 'Aufgaben',
	'task list' => 'Aufgabenliste',
	'task lists' => 'Aufgabenlisten',
	'tag' => 'Schlagwort',
	'tags' => 'Schlagworte',
	'attachment' => 'Anlage',
	'attachments' => 'Anlagen',
	'object subscribers' => 'Abonnenten',
	'form' => 'Formular',
	'forms' => 'Formulare',
	'file' => 'Datei',
	'files' => 'Dateien',
	'file revision' => 'Dateirevision',
	'file revisions' => 'Dateirevisionen',
	'revision' => 'Revision',
	'revisions' => 'Revisionen',
	'folder' => 'Ordner',
	'folders' => 'Ordner',
	'configuration category' => 'Konfigurationskategorie',
	'configuration categories' => 'Konfigurationskategorien',
	'handin' => 'Hand-In',
	'handins' => 'Hand-Ins',
	'owner company' => 'Unser Unternehmen',
	'client companies' => 'Andere Unternehmen',
	'open milestone' => 'Offener Meilenstein',
	'open milestones' => 'Offene Meilensteine',
	'completed milestone' => 'Abgeschlossener Meilenstein',
	'completed milestones' => 'Abgeschlossene Meilensteine',
	'late milestones' => 'Verspätete Meilensteine',
	'late milestones and tasks' => 'Verspätete Meilensteine und Aufgaben',
	'today milestones' => 'Heute fällige Meilensteine',
	'upcoming milestones' => 'Anstehende Meilensteine',
	'completed task list' => 'Abgeschlossene Aufgabe',
	'completed task lists' => 'Abgeschlossene Aufgaben',
	'open task list' => 'Offene Aufgabe',
	'open task lists' => 'Offene Aufgaben',
	'active project' => 'Aktueller Arbeitsbereich',
	'active projects' => 'Aktuelle Arbeitsbereiche',
	'finished project' => 'Geschlossener Arbeitsbereich',
	'finished projects' => 'Geschlossene Arbeitsbereiche',
	'linked object' => 'Verknüpftes Objekt',
	'linked objects' => 'Verknüpfte Objekte',
	'important message' => 'Wichtige Nachricht',
	'important messages' => 'Wichtige Nachrichten',
	'important file' => 'Wichtige Datei',
	'important files' => 'Wichtige Dateien',
	'parent task' => 'Hauptaufgabe',
	'private message' => 'Private Nachricht',
	'private milestone' => 'Privater Meilenstein',
	'private task list' => 'Private Aufgabenliste',
	'private comment' => 'Privater Kommentar',
	'private file' => 'Private Datei',
	'file contents' => 'Dateiinhalt',
	'emailunclassified' => 'E-Mail',
	'object reminders' => 'Erinnerungen',
	'add object reminder' => 'Erinnerung hinzufügen',
	'load file' => 'Datei laden',
	'time' => 'Zeit',
	'reporting' => 'Berichte',
	'create document' => 'Dokumente hinzufügen',
	'create presentation' => 'Präsentationen hinzufügen',
	'modify object subscribers' => 'Abonnenten bearbeiten',
	'subscription modified successfully' => 'Abonnenten erfolgreich bearbeitet!',
	'urgent milestone' => 'Dringend',
	'the message' => 'Notiz',
	'the email' => 'E-Mail',
	'the emailunclassified' => 'E-Mail',
	'the contact' => 'Kontakt',
	'the company' => 'Firma',
	'the event' => 'Termin',
	'the file' => 'Datei',
	'the file revision' => 'Dateirevision',
	'the task' => 'Aufgabe',
	'the milestone' => 'Meilenstein',
	'the webpage' => 'Weblink',
	'the comment' => 'Kommentar',
	'the user' => 'Benutzer',
	'the project' => 'Arbeitsbereich',
	'activity add' => '{1} fügte {0} „{2}“ hinzu.',
	'activity edit' => '{1} bearbeitete {0} „{2}“.',
	'activity delete' => '{1} löschte {0} „{2}“.',
	'activity trash' => '{1} löschte {0} „{2}“.',
	'activity untrash' => '{1} stellte {0} „{2}“ aus dem Papierkorb wieder her.',
	'activity open' => '{1} eröffnete {0} „{2}“ wieder.',
	'activity close' => '{1} markierte {0} „{2}“ als „Erledigt“.',
	'activity subscribe' => '{1} abonnierte für {3}: {0} „{2}“.',
	'activity unsubscribe' => '{1} kündigte Abonnent von {3} für {0} „{2}“.',
	'activity tag' => '{1} verschlagwortete {0} „{2}“ als „{3}“.',
	'activity untag' => '{1} löschte die Schlagwörter von {0} „{2}“.',
	'activity comment' => '{1} kommentierte {0} „{2}“:<br />    „{3}“',
	'activity link' => '{1} verknüpfte {0} „{2}“ mit {3} {4}.',
	'activity unlink' => '{1} löschte die Verknüpfung zwischen {0} „{2}“ und {3} {4}.',
	'activity login' => '{0} hat sich angemeldet.',
	'activity logout' => '{0} hat sich abgemeldet.',
	'activity archive' => '{1} archivierte {0} „{2}“.',
	'activity unarchive' => '{1} stellte {0} „{2}“ aus dem Archiv wieder her.',
	'activity move from to' => '{1} verschob {0} „{2}“ von {3} nach {4}.',
	'activity move from' => '{1} verschob {0} „{2}“ von {3}.',
	'activity move to' => '{1} verschob {0} „{2}“ nach {3}.',
	'activity move' => '{1} verschob {0} „{2}“ von {3}.',
	'activity copy to' => '{1} kopierte {0} „{2}“ nach {3}.',
	'activity copy' => '{1} kopierte {0} „{2}“.',
	'activity read' => '{1} las {0} „{2}“.',
	'activity download' => '{1} lud {0} „{2}“ herunter.',
	'x users' => '{0} Benutzer{1}',
	'the file_revision' => 'die Dateirevision',
); ?>
